@@ -129,6 +129,6 @@ function(l1_formula = 'NA', l2_formula = 'NA', data, id, l2_hyper, burnin, sampl
               coef.tables = coef.tables,
               pvalue.table = pvalue.table,
               conv = conv,
-              dMatrice = dMatrice, samples_l2_param = samples_l2_param, data = data, 
+              dMatrice = dMatrice, samples_l2_param = samples_l2_param, data = data, num_trials = 1,
               mf1 = mf1, mf2 = mf2, JAGSmodel = JAGS.model$sModel, single_level = F, model_name = "BANOVA.Bernoulli"))
 }
